@@ -20,7 +20,7 @@ use English                qw(-no_match_vars);
 use Carp                   qw(carp croak);
 use Cwd                    qw();
 
-our $VERSION     = '0.13';
+our $VERSION     = '0.14';
 our @EXPORT      = qw();
 our @EXPORT_OK   = qw(dist_pkgname dist_pkgver);
 our @EXPORT_TAGS = ( ':all' => \@EXPORT_OK );
@@ -454,12 +454,32 @@ sub dist_pkgver
     croak "Must provide arguments to pacman_version" if ( @_ == 0 );
     my ($version) = @_;
 
-    # Package versions should be letters, numbers and decimal points only...
-    $version =~ tr/_-/../s;
-    $version =~ tr/a-zA-Z0-9.//cd;
+    # Package versions should be numbers and decimal points only...
+    $version =~ tr/-/./;
+    $version =~ tr/0-9.-//cd;
+
+    # Developer packages have a ##_## at the end though...
+    unless (( $version =~ tr/_/_/ == 1 ) && ( $version =~ /\d_\d/ )) {
+        $version =~ tr/_/./;
+    }
+
+    $version =~ tr/././s;
+    $version =~ s/[.]$//;
+    $version =~ s/^[.]//;
+
     return $version;
 }
 
+=for Letters In Versions
+  Letters aren't allowed in versions because makepkg doesn't handle them
+  in dependencies.  Example:
+    * CAM::PDF requires Text::PDF 0.29
+    * Text::PDF 0.29a was built/installed
+    * makepkg still complains about perl-text-pdf>=0.29 is missing ... ?
+  So ... no more letters in versions.
+
+=cut
+
 
 #-------------------------------------------------------------------------------
 # PUBLIC METHODS
@@ -491,8 +511,9 @@ sub get_cpandistdir
     my ($self) = @_;
 
     my $module  = $self->parent;
-    my $distdir = $module->package;
-    $distdir    =~ s/ [.] ${\$module->package_extension} \z //xms;
+    my $distdir = $module->status->dist_cpan->status->distdir;
+    $distdir    =~ s{^.*/}{};
+
     return $distdir;
 }
 
